==> tencent_cloud_chat_sdk-7.7.5314.tar.gz: example/lib/pages/V2TIMFriendManager.dart <==
import 'package:flutter/material.dart';
import 'package:tencent_cloud_chat_sdk/enum/V2TimAdvancedMsgListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/addConversationListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/deleteConversation.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversation.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationListByConversationIds.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationListByFilter.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getTotalUnreadMessageCount.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/removeConversationListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/addFriendshipListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendApplicationList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendsInfo.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/removeFriendshipListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/addAdvancedMessageListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/clearC2CMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/clearGroupMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/getHistoryMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/removeAdvancedMessageListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/sendMessage.dart';

class V2TIMFriendshipManagerPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _V2TIMFriendshipManagerState();
  }
}

class _V2TIMFriendshipManagerState extends State<V2TIMFriendshipManagerPage> {
  @override
  Widget build(BuildContext context) {
    final ButtonStyle style = ElevatedButton.styleFrom(
      textStyle: const TextStyle(fontSize: 20),
      padding: EdgeInsets.symmetric(vertical: 15),
    );
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              leading: IconButton(
                onPressed: () => Navigator.pop(context),
                icon: Icon(Icons.arrow_back_ios),
              ),
              title: Text('V2TIMFriendshipManager'),
            ),
            body: Center(
              child: ListView(
                children: [
                  ElevatedButton(
                    child: Text('addFriendshipListener'),
                    style: style,
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => AddFriendshipListener()),
                      );
                    },
                  ),
                  ElevatedButton(
                    child: Text('removeFriendshipListener'),
                    style: style,
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => RemoveFriendshipeListener()),
                      );
                    },
                  ),
                  ElevatedButton(
                    child: Text('getFriendList'),
                    style: style,
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => GetFriendList()),
                      );
                    },
                  ),
                  ElevatedButton(
                    child: Text('getFriendsInfo'),
                    style: style,
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => GetFriendsInfo()),
                      );
                    },
                  ),
                  ElevatedButton(
                    child: Text('getFriendApplicationList'),
                    style: style,
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => GetFriendApplicationList()),
                      );
                    },
                  ),
                ],
              ),
            )));
  }
}

==> tencent_cloud_chat_sdk-7.7.5317.tar.gz: example/lib/pages/V2TIMFriendManager.dart <==
import 'package:flutter/material.dart';
import 'package:tencent_cloud_chat_sdk/enum/V2TimAdvancedMsgListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/addConversationListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/deleteConversation.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversation.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationListByConversationIds.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getConversationListByFilter.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/getTotalUnreadMessageCount.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMConversationManager/removeConversationListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/addFriendshipListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendApplicationList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/getFriendsInfo.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMFriendshipManager/removeFriendshipListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/addAdvancedMessageListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/clearC2CMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/clearGroupMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/getHistoryMessageList.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/removeAdvancedMessageListener.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMMessageManager/sendMessage.dart';

class V2TIMFriendshipManagerPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _V2TIMFriendshipManagerState();
  }
}

class _V2TIMFriendshipManagerState extends State<V2TIMFriendshipManagerPage> {
  @override
  Widget build(BuildContext context) {
    final ButtonStyle style = ElevatedButton.styleFrom(
      textStyle: const TextStyle(fontSize: 20),
      padding: EdgeInsets.symmetric(vertical: 15, horizontal: 10),
    );
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              leading: IconButton(
                onPressed: () => Navigator.pop(context),
                icon: Icon(Icons.arrow_back_ios),
              ),
              title: Text('V2TIMFriendshipManager 好友模块'),
            ),
            body: Center(
              child: Column(
                children: [
                  Row(
                    children: [
                      ElevatedButton(
                        child: Text('getFriendList 获取好友列表'),
                        style: style,
                        onPressed: () {
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => GetFriendList()),
                          );
                        },
                      ),
                      SizedBox(
                        width: 10,
                      ),
                      ElevatedButton(
                        child: Text('getFriendsInfo 获取指定好友资料'),
                        style: style,
                        onPressed: () {
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => GetFriendsInfo()),
                          );
                        },
                      ),
                    ],
                  ),
                  SizedBox(
                    height: 10,
                  ),
                  Row(
                    children: [
                      ElevatedButton(
                        child: Text('getFriendApplicationList 获取好友申请列表'),
                        style: style,
                        onPressed: () {
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) =>
                                    GetFriendApplicationList()),
                          );
                        },
                      ),
                    ],
                  ),
                ],
              ),
            )));
  }
}
